from django.conf.urls.defaults import *


urlpatterns = patterns('nomadblog.views',
    # List blog posts
    url(
        regex=r'^$',
        view='list_posts',
        name='list_posts',
    ),
    # Show single post, category + slug based URL
    url(
        regex=r'^(?P<category>\w+)/(?P<slug>[-\w]+)/$',
        view='show_post',
        name='show_post',
    ),
    # List categories
    url(
        regex=r'^categories/$',
        view='list_categories',
        name='list_categories',
    ),
    # List posts by category
    url(
        regex=r'^(?P<category>\w+)/$',
        view='list_posts_by_category',
        name='list_posts_by_category',
    ),
)



from django.db import models
from django.contrib.auth.models import User

try:
    from settings import NOMADBLOG_SINGLE_USER
except ImportError:
    NOMADBLOG_SINGLE_USER = False


class Blog(models.Model):
    user = models.ForeignKey(User)
    title = models.CharField(max_length=100)
    description = models.CharField(max_length=500)
    creation_date = models.DateTimeField(auto_now_add=True)

    def __unicode__(self):
        return '%s - %s' % (self.user, self.title)

    @models.permalink
    def get_absolute_url(self):
        filters = {}
        if not NOMADBLOG_SINGLE_USER:
            filters['username'] = self.user.username
        return ('list_posts', (), filters)


class Category(models.Model):
    name = models.CharField(max_length=100)

    def __unicode__(self):
        return self.name

    class Meta:
        verbose_name_plural = 'categories'


class Post(models.Model):
    PUBLIC_STATUS = 0
    DRAFT_STATUS = 1
    PRIVATE_STATUS = 2
    STATUS_CHOICES = (
        (PUBLIC_STATUS, 'public'),
        (DRAFT_STATUS, 'draft'),
        (PRIVATE_STATUS, 'private'),
    )
    blog = models.ForeignKey(Blog)
    pub_date = models.DateTimeField(auto_now_add=True)
    status = models.IntegerField(choices=STATUS_CHOICES, default=1)
    title = models.CharField(max_length=300)
    slug = models.SlugField(max_length=50, unique=True)
    category = models.ForeignKey(Category)
    content = models.TextField()

    @models.permalink
    def get_absolute_url(self):
        filters = {'category': self.category.name, 'slug': self.slug}
        if not NOMADBLOG_SINGLE_USER:
            filters['username'] = self.blog.user.username
        return ('show_post', (), filters)

    def __unicode__(self):
        return "%s - %s" % (self.blog.user, self.title)




from django.shortcuts import render_to_response
from django.http import Http404
from django.template import RequestContext
from django.contrib.auth.models import User
from django.core.exceptions import ObjectDoesNotExist
from django.shortcuts import get_object_or_404
from django.contrib.auth.models import User

from nomadblog.models import Post, Category


def _get_extra_filters(username=None):
    """
    Set a queryset param to filter by blog, if username is
    provided -- that is, Nomadblog is being used in a multi-user layout.
    """
    extra_filters = {}
    if username is not None:
        u = get_object_or_404(User, username=username)
        extra_filters['blog__user'] = u
    return extra_filters

def _list_posts(request, context=None, username=None):
    """Populates context with values required by list_posts view"""
    extra_filters = _get_extra_filters(username)
    posts = Post.objects.filter(status=Post.PUBLIC_STATUS,\
        **extra_filters).order_by('-pub_date')
    ctxt_dict = {'posts': posts}
    context = RequestContext(request, ctxt_dict) if context is None \
        else context.update(ctxt_dict)
    return context

def _show_post(request, category, slug, context=None, username=None):
    extra_filters = _get_extra_filters(username)
    cat = get_object_or_404(Category, name=category)
    post = get_object_or_404(Post, category=cat, slug=slug,
                             status=Post.PUBLIC_STATUS, **extra_filters)
    ctxt_dict = {'post': post}
    context = RequestContext(request, ctxt_dict) if context is None \
        else context.update(ctxt_dict)
    return context

def _list_categories(request, context=None, username=None):
    categories = Category.objects.all() # TODO: only cats from username
    ctxt_dict = {'categories': categories}
    context = RequestContext(request, ctxt_dict) if context is None \
        else context.update(ctxt_dict)
    return context

def _list_posts_by_category(request, category, context=None, username=None):
    extra_filters = _get_extra_filters(username)
    cat = get_object_or_404(Category, name=category)
    posts = Post.objects.filter(category=cat, status=Post.PUBLIC_STATUS, \
        **extra_filters).order_by('-pub_date')
    ctxt_dict = {'posts': posts, 'category': category}
    context = RequestContext(request, ctxt_dict) if context is None \
        else context.update(ctxt_dict)
    return context

def list_posts(request, username=None, template='nomadblog/list_posts.html'):
    """A list of posts, orderen in reverse chronological order."""
    context = _list_posts(request, username=username)
    return render_to_response(template, {}, context)

def show_post(request, category, slug, username=None,
              template='nomadblog/show_post.html'):
    context = _show_post(request, category, slug, username=username)
    return render_to_response(template, {}, context)

def list_categories(request, username=None,
                    template='nomadblog/list_categories.html'):
    context = _list_categories(request, username=username)
    return render_to_response(template, {}, context)

def list_posts_by_category(request, category,
                           username=None, render_response=True, context=None,
                           template='nomadblog/list_posts_by_category.html'):
    context = _list_posts_by_category(request, category, username=username)
    return render_to_response(template, {}, context)




import os
from distutils.core import setup

doc_dir = os.path.join(os.path.dirname(__file__), 'docs')
long_desc_file = os.path.join(doc_dir, 'overview.rst')
version_num = __import__('nomadblog').__version__ 

setup(
    name='django-nomadblog',
    version=version_num,
    description='A minimalist Django blogging system.',
    long_description=open(long_desc_file).read(),
    author='Hector Garcia',
    author_email='hector@nomadblue.com',
    url='http://nomadblue.com/projects/django-nomadblog/',
    download_url='http://bitbucket.org/nabucosound/django-nomadblog/downloads/django-nomadblog-%s.tar.gz' % version_num,
    packages=['nomadblog'],
    classifiers=[
      'Development Status :: 4 - Beta',
      'Environment :: Web Environment',
      'Intended Audience :: Developers',
      'License :: OSI Approved :: BSD License',
      'Operating System :: OS Independent',
      'Programming Language :: Python',
      'Framework :: Django',
    ]
)
